You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2013/01/08 11:11:17 UTC

svn commit: r1430199 - in /camel/trunk/components/camel-test-spring/src: main/java/org/apache/camel/test/junit4/ main/java/org/apache/camel/test/spring/ test/java/org/apache/camel/test/issues/ test/java/org/apache/camel/test/patterns/ test/java/org/apa...

Author: davsclaus
Date: Tue Jan  8 10:11:17 2013
New Revision: 1430199

URL: http://svn.apache.org/viewvc?rev=1430199&view=rev
Log:
CAMEL-5939: camel-test-spring - Deprecate classes in junit4 package to avoid split package problem with OSGi

Added:
    camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/spring/CamelSpringJUnit4ClassRunner.java
      - copied, changed from r1430193, camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringJUnit4ClassRunner.java
    camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/spring/CamelSpringTestSupport.java
      - copied, changed from r1430193, camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringTestSupport.java
Modified:
    camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringJUnit4ClassRunner.java
    camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringTestSupport.java
    camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/issues/AdviceWithOnExceptionMultipleIssueTest.java
    camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/patterns/DebugSpringTest.java
    camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/patterns/ProduceBeanTest.java
    camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/spring/CamelSpringActiveProfileTest.java
    camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/spring/CamelSpringJUnit4ClassRunnerPlainTest.java

Modified: camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringJUnit4ClassRunner.java
URL: http://svn.apache.org/viewvc/camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringJUnit4ClassRunner.java?rev=1430199&r1=1430198&r2=1430199&view=diff
==============================================================================
--- camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringJUnit4ClassRunner.java (original)
+++ camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringJUnit4ClassRunner.java Tue Jan  8 10:11:17 2013
@@ -16,77 +16,16 @@
  */
 package org.apache.camel.test.junit4;
 
-import java.util.LinkedHashSet;
-import java.util.Set;
-
-import org.apache.camel.test.spring.CamelSpringTestContextLoader;
-import org.apache.camel.test.spring.CamelSpringTestContextLoaderTestExecutionListener;
-import org.apache.camel.test.spring.DisableJmxTestExecutionListener;
-import org.apache.camel.test.spring.StopWatchTestExecutionListener;
 import org.junit.runners.model.InitializationError;
-import org.springframework.test.context.TestContextManager;
-import org.springframework.test.context.TestExecutionListener;
-import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
 
 /**
- * An implementation bringing the functionality of {@link CamelSpringTestSupport} to
- * Spring Test based test cases.  This approach allows developers to implement tests
- * for their Spring based applications/routes using the typical Spring Test conventions
- * for test development.
+ * @deprecated use {@link org.apache.camel.test.spring.CamelSpringJUnit4ClassRunner}
  */
-public class CamelSpringJUnit4ClassRunner extends SpringJUnit4ClassRunner {
+@Deprecated
+public class CamelSpringJUnit4ClassRunner extends org.apache.camel.test.spring.CamelSpringJUnit4ClassRunner {
 
     public CamelSpringJUnit4ClassRunner(Class<?> clazz) throws InitializationError {
         super(clazz);
     }
 
-    /**
-     * Returns the specialized manager instance that provides tight integration between Camel testing
-     * features and Spring.
-     * 
-     * @return a new instance of {@link CamelTestContextManager}.
-     */
-    @Override
-    protected TestContextManager createTestContextManager(Class<?> clazz) {
-        return new CamelTestContextManager(clazz, getDefaultContextLoaderClassName(clazz));
-    }
-    
-    /**
-     * Returns the specialized loader for tight integration between Camel testing features
-     * and the application context initialization.
-     * 
-     * @return Returns the class name for {@link CamelSpringTestContextLoader}
-     */
-    @Override
-    protected String getDefaultContextLoaderClassName(Class<?> clazz) {
-        return CamelSpringTestContextLoader.class.getName();
-    }
-
-    /**
-     * An implementation providing additional integration between Spring Test and Camel
-     * testing features.
-     */
-    public static final class CamelTestContextManager extends TestContextManager {
-
-        public CamelTestContextManager(Class<?> testClass, String defaultContextLoaderClassName) {
-            super(testClass, defaultContextLoaderClassName);
-        }
-
-        /**
-         * Augments the default listeners with additional listeners to provide support
-         * for the Camel testing features.
-         */
-        @Override
-        protected Set<Class<? extends TestExecutionListener>> getDefaultTestExecutionListenerClasses() {
-            Set<Class<? extends TestExecutionListener>> classes = new LinkedHashSet<Class<? extends TestExecutionListener>>();
-
-            classes.add(CamelSpringTestContextLoaderTestExecutionListener.class);
-            classes.addAll(super.getDefaultTestExecutionListenerClasses());
-            classes.add(DisableJmxTestExecutionListener.class);
-            classes.add(StopWatchTestExecutionListener.class);
-
-            return classes;
-        }
-    }
-
 }

Modified: camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringTestSupport.java
URL: http://svn.apache.org/viewvc/camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringTestSupport.java?rev=1430199&r1=1430198&r2=1430199&view=diff
==============================================================================
--- camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringTestSupport.java (original)
+++ camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringTestSupport.java Tue Jan  8 10:11:17 2013
@@ -16,205 +16,9 @@
  */
 package org.apache.camel.test.junit4;
 
-import java.util.Arrays;
-import java.util.HashSet;
-import java.util.List;
-
-import org.apache.camel.CamelContext;
-import org.apache.camel.spring.CamelBeanPostProcessor;
-import org.apache.camel.spring.SpringCamelContext;
-import org.apache.camel.test.ExcludingPackageScanClassResolver;
-import org.apache.camel.util.ObjectHelper;
-import org.junit.After;
-import org.junit.AfterClass;
-import org.springframework.beans.factory.support.RootBeanDefinition;
-import org.springframework.context.ApplicationContext;
-import org.springframework.context.support.AbstractApplicationContext;
-import org.springframework.context.support.GenericApplicationContext;
-
 /**
- * @version 
+ * @deprecated use {@link org.apache.camel.test.spring.CamelSpringTestSupport}
  */
-public abstract class CamelSpringTestSupport extends CamelTestSupport {
-    protected static ThreadLocal<AbstractApplicationContext> threadAppContext = new ThreadLocal<AbstractApplicationContext>();
-    protected static Object lock = new Object();
-    
-    protected AbstractApplicationContext applicationContext;
-    protected abstract AbstractApplicationContext createApplicationContext();
-
-    /**
-     * Lets post process this test instance to process any Camel annotations.
-     * Note that using Spring Test or Guice is a more powerful approach.
-     */
-    @Override
-    public void postProcessTest() throws Exception {
-        super.postProcessTest();
-        if (isCreateCamelContextPerClass()) {
-            applicationContext = threadAppContext.get();
-        }
-
-        // use the bean post processor from camel-spring
-        CamelBeanPostProcessor processor = new CamelBeanPostProcessor();
-        processor.setApplicationContext(applicationContext);
-        processor.setCamelContext(context);
-        processor.postProcessBeforeInitialization(this, getClass().getName());
-        processor.postProcessAfterInitialization(this, getClass().getName());
-    }
-
-    @Override
-    public void doPreSetup() throws Exception {
-        if (!"true".equalsIgnoreCase(System.getProperty("skipStartingCamelContext"))) {
-            // tell camel-spring it should not trigger starting CamelContext, since we do that later
-            // after we are finished setting up the unit test
-            synchronized (lock) {
-                SpringCamelContext.setNoStart(true);
-                if (isCreateCamelContextPerClass()) {
-                    applicationContext = threadAppContext.get();
-                    if (applicationContext == null) {
-                        applicationContext = doCreateApplicationContext();
-                        threadAppContext.set(applicationContext);
-                    }
-                } else {
-                    applicationContext = doCreateApplicationContext();
-                }
-                SpringCamelContext.setNoStart(false);
-            }
-        } else {
-            log.info("Skipping starting CamelContext as system property skipStartingCamelContext is set to be true.");
-        }
-    }
-
-    private AbstractApplicationContext doCreateApplicationContext() {
-        AbstractApplicationContext context = createApplicationContext();
-        assertNotNull("Should have created a valid Spring application context", context);
-
-        String[] profiles = activeProfiles();
-        if (profiles != null && profiles.length > 0) {
-            // the context must not be active
-            if (context.isActive()) {
-                throw new IllegalStateException("Cannot active profiles: " + Arrays.asList(profiles) + " on active Spring application context: " + context
-                    + ". The code in your createApplicationContext() method should be adjusted to create the application context with refresh = false as parameter");
-            }
-            log.info("Spring activating profiles: {}", Arrays.asList(profiles));
-            context.getEnvironment().setActiveProfiles(profiles);
-        }
-
-        // ensure the context has been refreshed at least once
-        if (!context.isActive()) {
-            context.refresh();
-        }
-
-        return context;
-    }
-
-    @Override
-    @After
-    public void tearDown() throws Exception {
-        super.tearDown();
-
-        if (!isCreateCamelContextPerClass()) {
-            if (applicationContext != null) {
-                applicationContext.destroy();
-                applicationContext = null;
-            }
-        }
-    }
-
-    @AfterClass
-    public static void tearSpringDownAfterClass() throws Exception {
-        if (threadAppContext.get() != null) {
-            threadAppContext.get().destroy();
-            threadAppContext.remove();
-        }
-    }
-    
-    /**
-     * Create a parent context that initializes a
-     * {@link org.apache.camel.spi.PackageScanClassResolver} to exclude a set of given classes from
-     * being resolved. Typically this is used at test time to exclude certain routes,
-     * which might otherwise be just noisy, from being discovered and initialized.
-     * <p/>
-     * To use this filtering mechanism it is necessary to provide the
-     * {@link ApplicationContext} returned from here as the parent context to
-     * your test context e.g.
-     *
-     * <pre>
-     * protected AbstractXmlApplicationContext createApplicationContext() {
-     *     return new ClassPathXmlApplicationContext(new String[] {&quot;test-context.xml&quot;}, getRouteExcludingApplicationContext());
-     * }
-     * </pre>
-     *
-     * This will, in turn, call the template methods <code>excludedRoutes</code>
-     * and <code>excludedRoute</code> to determine the classes to be excluded from scanning.
-     *
-     * @return ApplicationContext a parent {@link ApplicationContext} configured
-     *         to exclude certain classes from package scanning
-     */
-    protected ApplicationContext getRouteExcludingApplicationContext() {
-        GenericApplicationContext routeExcludingContext = new GenericApplicationContext();
-        routeExcludingContext.registerBeanDefinition("excludingResolver", new RootBeanDefinition(ExcludingPackageScanClassResolver.class));
-        routeExcludingContext.refresh();
-
-        ExcludingPackageScanClassResolver excludingResolver = routeExcludingContext.getBean("excludingResolver", ExcludingPackageScanClassResolver.class);
-        List<Class<?>> excluded = Arrays.asList(excludeRoutes());
-        excludingResolver.setExcludedClasses(new HashSet<Class<?>>(excluded));
-
-        return routeExcludingContext;
-    }
-
-    /**
-     * Template method used to exclude {@link org.apache.camel.Route} from the test time context
-     * route scanning
-     *
-     * @return Class[] the classes to be excluded from test time context route scanning
-     */
-    protected Class<?>[] excludeRoutes() {
-        Class<?> excludedRoute = excludeRoute();
-        return excludedRoute != null ? new Class[] {excludedRoute} : new Class[0];
-    }
-
-    /**
-     * Template method used to exclude a {@link org.apache.camel.Route} from the test camel context
-     */
-    protected Class<?> excludeRoute() {
-        return null;
-    }
-
-    /**
-     * Looks up the mandatory spring bean of the given name and type, failing if
-     * it is not present or the correct type
-     */
-    public <T> T getMandatoryBean(Class<T> type, String name) {
-        Object value = applicationContext.getBean(name);
-        assertNotNull("No spring bean found for name <" + name + ">", value);
-        if (type.isInstance(value)) {
-            return type.cast(value);
-        } else {
-            fail("Spring bean <" + name + "> is not an instanceof " + type.getName() + " but is of type " + ObjectHelper.className(value));
-            return null;
-        }
-    }
-
-    /**
-     * Which active profiles should be used.
-     * <p/>
-     * <b>Important:</b> When using active profiles, then the code in {@link #createApplicationContext()} should create
-     * the Spring {@link AbstractApplicationContext} without refreshing. For example creating an
-     * {@link org.springframework.context.support.ClassPathXmlApplicationContext} you would need to pass in
-     * <tt>false</tt> in the refresh parameter, in the constructor.
-     * Camel will thrown an {@link IllegalStateException} if this is not correct stating this problem.
-     * The reason is that we cannot active profiles <b>after</b> a Spring application context has already
-     * been refreshed, and is active.
-     *
-     * @return an array of active profiles to use, use <tt>null</tt> to not use any active profiles.
-     */
-    protected String[] activeProfiles() {
-        return null;
-    }
-
-    @Override
-    protected CamelContext createCamelContext() throws Exception {
-        // don't start the springCamelContext if we
-        return SpringCamelContext.springCamelContext(applicationContext, false);
-    }
+@Deprecated
+public abstract class CamelSpringTestSupport extends org.apache.camel.test.spring.CamelSpringTestSupport {
 }

Copied: camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/spring/CamelSpringJUnit4ClassRunner.java (from r1430193, camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringJUnit4ClassRunner.java)
URL: http://svn.apache.org/viewvc/camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/spring/CamelSpringJUnit4ClassRunner.java?p2=camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/spring/CamelSpringJUnit4ClassRunner.java&p1=camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringJUnit4ClassRunner.java&r1=1430193&r2=1430199&rev=1430199&view=diff
==============================================================================
--- camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringJUnit4ClassRunner.java (original)
+++ camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/spring/CamelSpringJUnit4ClassRunner.java Tue Jan  8 10:11:17 2013
@@ -14,22 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.camel.test.junit4;
+package org.apache.camel.test.spring;
 
 import java.util.LinkedHashSet;
 import java.util.Set;
 
-import org.apache.camel.test.spring.CamelSpringTestContextLoader;
-import org.apache.camel.test.spring.CamelSpringTestContextLoaderTestExecutionListener;
-import org.apache.camel.test.spring.DisableJmxTestExecutionListener;
-import org.apache.camel.test.spring.StopWatchTestExecutionListener;
 import org.junit.runners.model.InitializationError;
 import org.springframework.test.context.TestContextManager;
 import org.springframework.test.context.TestExecutionListener;
 import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
 
 /**
- * An implementation bringing the functionality of {@link CamelSpringTestSupport} to
+ * An implementation bringing the functionality of {@link org.apache.camel.test.junit4.CamelSpringTestSupport} to
  * Spring Test based test cases.  This approach allows developers to implement tests
  * for their Spring based applications/routes using the typical Spring Test conventions
  * for test development.
@@ -43,19 +39,19 @@ public class CamelSpringJUnit4ClassRunne
     /**
      * Returns the specialized manager instance that provides tight integration between Camel testing
      * features and Spring.
-     * 
+     *
      * @return a new instance of {@link CamelTestContextManager}.
      */
     @Override
     protected TestContextManager createTestContextManager(Class<?> clazz) {
         return new CamelTestContextManager(clazz, getDefaultContextLoaderClassName(clazz));
     }
-    
+
     /**
      * Returns the specialized loader for tight integration between Camel testing features
      * and the application context initialization.
-     * 
-     * @return Returns the class name for {@link CamelSpringTestContextLoader}
+     *
+     * @return Returns the class name for {@link org.apache.camel.test.spring.CamelSpringTestContextLoader}
      */
     @Override
     protected String getDefaultContextLoaderClassName(Class<?> clazz) {

Copied: camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/spring/CamelSpringTestSupport.java (from r1430193, camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringTestSupport.java)
URL: http://svn.apache.org/viewvc/camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/spring/CamelSpringTestSupport.java?p2=camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/spring/CamelSpringTestSupport.java&p1=camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringTestSupport.java&r1=1430193&r2=1430199&rev=1430199&view=diff
==============================================================================
--- camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/issues/AdviceWithOnExceptionMultipleIssueTest.java (original)
+++ camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/issues/AdviceWithOnExceptionMultipleIssueTest.java Tue Jan  8 10:11:17 2013
@@ -19,7 +19,7 @@ package org.apache.camel.test.issues;
 import org.apache.camel.Exchange;
 import org.apache.camel.Processor;
 import org.apache.camel.builder.AdviceWithRouteBuilder;
-import org.apache.camel.test.junit4.CamelSpringTestSupport;
+import org.apache.camel.test.spring.CamelSpringTestSupport;
 import org.junit.Test;
 import org.springframework.context.support.AbstractApplicationContext;
 import org.springframework.context.support.ClassPathXmlApplicationContext;

Modified: camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/patterns/DebugSpringTest.java
URL: http://svn.apache.org/viewvc/camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/patterns/DebugSpringTest.java?rev=1430199&r1=1430198&r2=1430199&view=diff
==============================================================================
--- camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/patterns/DebugSpringTest.java (original)
+++ camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/patterns/DebugSpringTest.java Tue Jan  8 10:11:17 2013
@@ -20,7 +20,7 @@ import org.apache.camel.Exchange;
 import org.apache.camel.Processor;
 import org.apache.camel.builder.RouteBuilder;
 import org.apache.camel.model.ProcessorDefinition;
-import org.apache.camel.test.junit4.CamelSpringTestSupport;
+import org.apache.camel.test.spring.CamelSpringTestSupport;
 import org.junit.Test;
 import org.springframework.context.support.AbstractApplicationContext;
 import org.springframework.context.support.GenericApplicationContext;

Modified: camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/patterns/ProduceBeanTest.java
URL: http://svn.apache.org/viewvc/camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/patterns/ProduceBeanTest.java?rev=1430199&r1=1430198&r2=1430199&view=diff
==============================================================================
--- camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/patterns/ProduceBeanTest.java (original)
+++ camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/patterns/ProduceBeanTest.java Tue Jan  8 10:11:17 2013
@@ -16,7 +16,7 @@
  */
 package org.apache.camel.test.patterns;
 
-import org.apache.camel.test.junit4.CamelSpringTestSupport;
+import org.apache.camel.test.spring.CamelSpringTestSupport;
 import org.junit.Test;
 import org.springframework.context.support.AbstractApplicationContext;
 import org.springframework.context.support.ClassPathXmlApplicationContext;

Modified: camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/spring/CamelSpringActiveProfileTest.java
URL: http://svn.apache.org/viewvc/camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/spring/CamelSpringActiveProfileTest.java?rev=1430199&r1=1430198&r2=1430199&view=diff
==============================================================================
--- camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/spring/CamelSpringActiveProfileTest.java (original)
+++ camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/spring/CamelSpringActiveProfileTest.java Tue Jan  8 10:11:17 2013
@@ -20,7 +20,6 @@ import org.apache.camel.CamelContext;
 import org.apache.camel.Produce;
 import org.apache.camel.ProducerTemplate;
 import org.apache.camel.component.mock.MockEndpoint;
-import org.apache.camel.test.junit4.CamelSpringJUnit4ClassRunner;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.springframework.beans.factory.annotation.Autowired;

Modified: camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/spring/CamelSpringJUnit4ClassRunnerPlainTest.java
URL: http://svn.apache.org/viewvc/camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/spring/CamelSpringJUnit4ClassRunnerPlainTest.java?rev=1430199&r1=1430198&r2=1430199&view=diff
==============================================================================
--- camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/spring/CamelSpringJUnit4ClassRunnerPlainTest.java (original)
+++ camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/spring/CamelSpringJUnit4ClassRunnerPlainTest.java Tue Jan  8 10:11:17 2013
@@ -25,7 +25,6 @@ import org.apache.camel.ProducerTemplate
 import org.apache.camel.ServiceStatus;
 import org.apache.camel.component.mock.MockEndpoint;
 import org.apache.camel.management.DefaultManagementStrategy;
-import org.apache.camel.test.junit4.CamelSpringJUnit4ClassRunner;
 import org.apache.camel.util.StopWatch;
 
 import org.junit.Test;
--- camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/junit4/CamelSpringTestSupport.java (original)
+++ camel/trunk/components/camel-test-spring/src/main/java/org/apache/camel/test/spring/CamelSpringTestSupport.java Tue Jan  8 10:11:17 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.camel.test.junit4;
+package org.apache.camel.test.spring;
 
 import java.util.Arrays;
 import java.util.HashSet;
@@ -24,6 +24,7 @@ import org.apache.camel.CamelContext;
 import org.apache.camel.spring.CamelBeanPostProcessor;
 import org.apache.camel.spring.SpringCamelContext;
 import org.apache.camel.test.ExcludingPackageScanClassResolver;
+import org.apache.camel.test.junit4.CamelTestSupport;
 import org.apache.camel.util.ObjectHelper;
 import org.junit.After;
 import org.junit.AfterClass;
@@ -135,7 +136,7 @@ public abstract class CamelSpringTestSup
      * which might otherwise be just noisy, from being discovered and initialized.
      * <p/>
      * To use this filtering mechanism it is necessary to provide the
-     * {@link ApplicationContext} returned from here as the parent context to
+     * {@link org.springframework.context.ApplicationContext} returned from here as the parent context to
      * your test context e.g.
      *
      * <pre>
@@ -147,7 +148,7 @@ public abstract class CamelSpringTestSup
      * This will, in turn, call the template methods <code>excludedRoutes</code>
      * and <code>excludedRoute</code> to determine the classes to be excluded from scanning.
      *
-     * @return ApplicationContext a parent {@link ApplicationContext} configured
+     * @return ApplicationContext a parent {@link org.springframework.context.ApplicationContext} configured
      *         to exclude certain classes from package scanning
      */
     protected ApplicationContext getRouteExcludingApplicationContext() {
@@ -199,7 +200,7 @@ public abstract class CamelSpringTestSup
      * Which active profiles should be used.
      * <p/>
      * <b>Important:</b> When using active profiles, then the code in {@link #createApplicationContext()} should create
      * the Spring {@link AbstractApplicationContext} without refreshing. For example creating an
      * {@link org.springframework.context.support.ClassPathXmlApplicationContext} you would need to pass in
      * <tt>false</tt> in the refresh parameter, in the constructor.
      * Camel will thrown an {@link IllegalStateException} if this is not correct stating this problem.
@@ -199,7 +200,7 @@ public abstract class CamelSpringTestSup
      * <p/>
      * <b>Important:</b> When using active profiles, then the code in {@link #createApplicationContext()} should create
-     * the Spring {@link AbstractApplicationContext} without refreshing. For example creating an
+     * the Spring {@link org.springframework.context.support.AbstractApplicationContext} without refreshing. For example creating an
      * {@link org.springframework.context.support.ClassPathXmlApplicationContext} you would need to pass in
      * <tt>false</tt> in the refresh parameter, in the constructor.

Modified: camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/issues/AdviceWithOnExceptionMultipleIssueTest.java
URL: http://svn.apache.org/viewvc/camel/trunk/components/camel-test-spring/src/test/java/org/apache/camel/test/issues/AdviceWithOnExceptionMultipleIssueTest.java?rev=1430199&r1=1430198&r2=1430199&view=diff
==============================================================================